@@ -15,12 +15,14 @@ load_schema = _schema.load_schema
 parse_schema = _schema.parse_schema
 fullname = _schema.fullname
 expand_schema = _schema.expand_schema
+load_schema_ordered = _schema.load_schema_ordered
 
 __all__ = [
-    'UnknownType',
-    'load_schema',
-    'SchemaParseException',
-    'parse_schema',
-    'fullname',
-    'expand_schema',
+    "UnknownType",
+    "load_schema",
+    "SchemaParseException",
+    "parse_schema",
+    "fullname",
+    "expand_schema",
+    "load_schema_ordered",
 ]
